==> redux-http-middleware-0.0.3.tgz: package/lib/redux-http-middleware.js <==
'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _httpMethods = require('./constants/httpMethods');

var httpMethods = _interopRequireWildcard(_httpMethods);

var _dispatch = require('./dispatch');

var _client = require('./client');

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

var calculateMethodMaybe = function calculateMethodMaybe(action) {
  var methods = Object.keys(httpMethods);
  return methods.find(function (method) {
    return action[method] === httpMethods[method];
  });
};

var reduxHttpMiddleware = function reduxHttpMiddleware(client) {
  return function (store) {
    return function (next) {
      return function (action) {
        var method = calculateMethodMaybe(action);

        var isRelevantAction = Boolean(method);
        if (!isRelevantAction) {
          return next(action);
        }

        (0, _dispatch.dispatchOnRequest)({ action: action, store: store, method: method });

        var args = (0, _client.calculateClientArgs)({ method: method, action: action });
        return client(args).then(function (response) {
          return (0, _dispatch.dispatchOnResponse)({ action: action, store: store, response: response, method: method });
        }).catch(function (response) {
          return (0, _dispatch.dispatchOnError)({ action: action, store: store, response: response, method: method });
        });
      };
    };
  };
};

module.exports = _extends({}, httpMethods, {
  reduxHttpMiddleware: reduxHttpMiddleware
});

==> redux-http-middleware-1.0.7.tgz: package/lib/redux-http-middleware.js <==
'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _httpMethods = require('./constants/httpMethods');

var httpMethods = _interopRequireWildcard(_httpMethods);

var _dispatch = require('./dispatch');

var _client = require('./client');

var _find = require('lodash/find');

var _find2 = _interopRequireDefault(_find);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

var calculateMethodMaybe = function calculateMethodMaybe(action) {
  var methods = Object.keys(httpMethods);
  return (0, _find2.default)(methods, function (method) {
    return action[method] === httpMethods[method];
  });
};

var reduxHttpMiddleware = function reduxHttpMiddleware(client) {
  return function (store) {
    return function (next) {
      return function (action) {
        var method = calculateMethodMaybe(action);

        var isRelevantAction = Boolean(method);
        if (!isRelevantAction) {
          return next(action);
        }

        (0, _dispatch.dispatchOnRequest)({ action: action, store: store, method: method });

        var args = (0, _client.calculateClientArgs)({ method: method, action: action });
        return client(args).then(function (response) {
          return (0, _dispatch.dispatchOnResponse)({ action: action, store: store, response: response, method: method });
        }).catch(function (response) {
          return (0, _dispatch.dispatchOnError)({ action: action, store: store, response: response, method: method });
        });
      };
    };
  };
};

module.exports = _extends({}, httpMethods, {
  reduxHttpMiddleware: reduxHttpMiddleware
});
